# Workflow Agent Sample - SequentialAgent

Sample query:

* Write a quicksort method in python.
* Write a python function to do bubble sort.

To run in cli (after installing `google-adk`):

* `uv run main.py` (or `python main.py`)

Check sample output in `sample.output` file in this folder.
